/*
 * @brief Defines the context manager
 * @file src/com/ZmqContext.h
 * @author Sven Czarnian <devel@svcz.de>
 * @copyright Copyright 2021 Sven Czarnian
 * @license This project is published under the GNU General Public License v3 (GPLv3)
 */

#pragma once

#include <memory>

#include <zmq.hpp>

namespace aman {
    /**
     * @brief Handles the ZMQ context information
     */
    class ZmqContext {
    private:
        ZmqContext();

        std::unique_ptr<zmq::context_t> m_context;

    public:
        ZmqContext(const ZmqContext&) = delete;
        ZmqContext(ZmqContext&&) = delete;
        ZmqContext& operator=(const ZmqContext&) = delete;
        ZmqContext& operator=(ZmqContext&&) = delete;

        /**
         * @brief Initializes the ZMQ context
         */
        void initialize();
        /**
         * @brief Destroys the ZMQ context and all sockets need to be closed before
         */
        void deinitialize();

        /**
         * @brief Returns the system wide context
         * @return The ZMQ context
         */
        zmq::context_t& context();
        static ZmqContext& instance();
    };
}
